qpsphere documentation
======================

Qpsphere is a Python3 library for analyzing spherical objects
in quantitative phase imaging. This includes the extraction
of average refractive index and object radius, for which
several methods are implemented.
This is the documentaion of qpsphere version |release|.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   sec_introduction
   sec_getting_started
   sec_code_reference
   sec_bibliography


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
